Cockpit — setupjavax documentation

# Cockpit

## Command Line Interface

> Command extensions for setup.py - see also overview of Setuplib Commands.

## API

For the common extensions interface:

>     python  setup.py <command> [<cli-options>]
>     ipython setup.py <command> [<cli-options>]
>     ipw.exe setup.py <command> [<cli-options>]
>     jython  setup.py <command> [<cli-options>]
>     pypy    setup.py <command> [<cli-options>]

refer to:

> commands | cli options | module | API
> --- | --- | --- | ---
> build_jy | setup.py build_jy | build_java | setupjavax.build_java.BuildJava
> build_java | setup.py build_java | build_jy | setupjavax.build_jy.BuildJy